
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  SASL_conf.pm - psgconf action class for SASL application config files
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Action::GenerateFile::SASL_conf;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);

###############################################################################
###  generate method
###############################################################################

sub generate
{
    my ( $self, $fh, $psgconf ) = @_;
    my ($opt);

    foreach $opt ( sort keys %{ $self->{options} } )
    {
        print $fh $opt . ': ' . $self->{options}->{$opt} . "\n";
    }

    return 1;
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::SASL_conf - generate SASL config files

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::SASL_conf;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::SASL_conf->new(
			'name'		=> '/path/to/file',
			'options'	=> {
				'opt1'		=> 'value1',
				...
			},
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::SASL_conf>
module provides a B<PSGConf> action class for generating B<SASL>
configuration files.

The B<PSGConf::Action::GenerateFile::SASL_conf> class
is derived from the B<PSGConf::Action::GenerateFile> class, but it
defines/overrides the following methods:

=over 4

=item generate()

Generates the B<SASL> configuration file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::SASL_conf> class supports the following
attributes:

=over 4

=item I<options>

An anonymous hash containing the options to set in the config file.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut

