
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  PSGConf::Action::GenerateFile::etc_system - action to generate /etc/system
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Action::GenerateFile::etc_system;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);

###############################################################################
###  generate method
###############################################################################

sub generate
{
    my ( $self, $fh, $psgconf ) = @_;

    map { print $fh "set $_=$self->{system_vars}->{$_}\n"; }
      sort keys %{ $self->{system_vars} };

    print $fh "\n$self->{system_literal}\n"
      if ( defined( $self->{system_literal} ) );

    return 1;
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::etc_system - generate Solaris /etc/system file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::etc_system;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::etc_system->new(
			'name'		=> '/etc/system',
			'system_vars'	=> {
				'var'	=> '...',
				...
			},
			'system_literal' => '...',
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::etc_system> module provides a
B<PSGConf> action class for generating the Solaris F</etc/system> file.

The B<PSGConf::Action::GenerateFile::etc_system> class is derived from the
B<PSGConf::Action::GenerateFile> class, but it defines/overrides the
following methods:

=over 4

=item generate()

Creates the F</etc/system> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::etc_system> class supports the following
attributes:

=over 4

=item I<system_vars>

A hash mapping variables to their values.

=item I<system_literal>

A string containing literal text to be appended to the file.

=back

=head1 BUGS

The I<system_literal> attribute is a hack.  It should be replaced with
custom attributes for the other types of directives in F</etc/system>.

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut

