
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  mime_types.pm - psgconf action class for generating Apache mime.types
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Action::GenerateFile::mime_types;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);

###############################################################################
###  generate() method
###############################################################################

sub generate
{
    my ( $self, $fh, $psgconf ) = @_;
    my ($type);

    foreach $type ( sort keys %{ $self->{types} } )
    {
        if ( !defined( $self->{types}->{$type} ) )
        {
            print $fh "$type\n";
            next;
        }

        printf $fh '%-32s', $type;
        map { print $fh " $_"; } sort keys %{ $self->{types}->{$type} };
        print $fh "\n";
    }

    return 1;
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::mime_types - action to generate Apache mime.types

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::mime_types;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::etc_services->new(
			'name'	=> '/usr/local/etc/apache/mime.types',
			'types'	=> {
				"application/postscript" => {
					ai => undef,
					eps => undef,
					ps => undef,
					...
					},
				...
				},
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::mime_types> module provides a
B<PSGConf> action class for generating the Apache F<mime.types> file.

The B<PSGConf::Action::GenerateFile::mime_types> class is derived from
the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generates the F<mime.types> file based on the value of the I<types>
attribute.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::etc_services> class supports the
following attributes:

=over 4

=item I<types>

A reference to a hash that maps MIME types (e.g., "application/postscript")
to an anonymous hash whose keys are the extensions that are used for
that MIME type.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


