
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  PSGConf::Action::GenerateFile::nsswitch_conf - /etc/nsswitch.conf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Action::GenerateFile::nsswitch_conf;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);

###############################################################################
###  generate method
###############################################################################

sub generate
{
    my ( $self, $fh, $psgconf ) = @_;
    my ( $name_service_switch, $type );

    $name_service_switch = $self->{name_service_switch};

    foreach $type ( sort keys %$name_service_switch )
    {
        if ( length($type) )
        {
            print $fh $type;
            print $fh $self->{name_service_delimiter}
              if ( defined( $self->{name_service_delimiter} ) );
        }

        printf $fh "%s\n",
          join(
            $self->{name_service_seperator},
            @{ $name_service_switch->{$type} }
          );
    }

    return 1;
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::nsswitch_conf - generate /etc/nsswitch.conf file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::nsswitch_conf;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::nsswitch_conf->new(
			'name'		=> '/etc/nsswitch.conf',
			'name_service_delimiter'	=> ': ',
			'name_service_seperator'	=> ' ',
			'name_service_switch'	=> '...',
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::nsswitch_conf> module provides a
B<PSGConf> action class for generating the F</etc/nsswitch.conf> file.

The B<PSGConf::Action::GenerateFile::nsswitch_conf> class is derived
from the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generate the F</etc/nsswitch.conf> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::nsswitch_conf> class supports the following
attributes:

=over 4

=item I<name_service_switch>

The hash of arrays configuring the name services on the system.

=item I<name_service_delimiter>

The character used to seperate the name service from the services to use.

=item I<name_service_seperator>

The character used to seperate the names of the services to use.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut

