
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  PSGConf::Action::GenerateFile::resolv_conf - action to generate resolv.conf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Action::GenerateFile::resolv_conf;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);

###############################################################################
###  generate method
###############################################################################

sub generate
{
    my ( $self, $fh, $psgconf ) = @_;

    return 0
      if ( !exists $self->{dns_servers} || !scalar @{ $self->{dns_servers} } );

    print $fh "domain $self->{domain}\n"
      if ( defined( $self->{domain} ) );

    print $fh 'search ' . join( ' ', @{ $self->{dns_search} } ) . "\n"
      if ( exists( $self->{dns_search} ) && scalar @{ $self->{dns_search} } );

    print $fh 'sortlist ' . join( ' ', @{ $self->{dns_sortlist} } ) . "\n"
      if ( exists( $self->{dns_sortlist} )
        && scalar @{ $self->{dns_sortlist} } );

    map { print $fh "nameserver $_\n"; } @{ $self->{dns_servers} };

    return 1;
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::resolv_conf - generate /etc/resolv.conf file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::resolv_conf;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::resolv_conf->new(
			'name'		=> '/etc/resolv.conf',
			'domain'	=> '...',
			'dns_search'	=> [ ... ],
			'dns_servers'	=> [ ... ],
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::resolv_conf> module provides a B<PSGConf>
action class for generating the F</etc/resolv.conf> file.

The B<PSGConf::Action::GenerateFile::resolv_conf> class is derived from the
B<PSGConf::Action::GenerateFile> class, but it defines/overrides the
following methods:

=over 4

=item generate()

Generate the F</etc/resolv.conf> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::resolv_conf> class supports the following
attributes:

=over 4

=item I<domain>

The default domain for DNS lookups.  This attribute may not be specified
with the I<dns_search> attribute.

=item I<dns_search>

A list of domains to search for DNS lookups.  This attribute may not be
specified with the I<domain> attribute.

=item I<dns_servers>

A list of IP addresses of DNS servers to use.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut

