
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  sendmail_map.pm - psgconf action to generate sendmail map files
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Action::GenerateFile::sendmail_map;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);

###############################################################################
###  generate() method
###############################################################################

sub generate
{
    my ( $self, $fh, $psgconf ) = @_;
    my ($key);

    foreach $key ( sort keys %{ $self->{entries} } )
    {
        print $fh "$key\t$self->{entries}->{$key}\n";
    }

    return 1;
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::sendmail_map - generate sendmail map files

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::sendmail_map;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::sendmail_map->new(
			name		=> '/etc/mail/access',
			description	=> 'sendmail access map',
			entries		=> {
				'Connect:uiuc.edu'	=> 'RELAY',
				...
			},
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::sendmail_map> module provides
a B<PSGConf> action class for generating the C<sendmail> map files.

The B<PSGConf::Action::GenerateFile::sendmail_map> class is derived
from the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generates the map file based on the I<entries> attribute (see below).

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::sendmail_map> class supports the
following attributes:

=over 4

=item I<entries>

A hash mapping keys to their values.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


