
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  tsm_inclexcl.pm - psgconf action to generate TSM inex.list file
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Action::GenerateFile::tsm_inclexcl;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);

###############################################################################
###  generate method
###############################################################################

sub generate
{
    my ( $self, $fh, $psgconf ) = @_;
    my ($row);

    ### Just dump the table in order (much easier than the Hash code)
    foreach $row ( @{ $self->{inex} } )
    {
        if (   exists $row->[0]
            && exists $row->[1]
            && $row->[0] =~ m/^(in)|(ex)clude/ )
        {
            print $fh $row->[0] . ' ' . $row->[1];
            print $fh ' ' . $row->[2] if ( exists $row->[2] );
            print $fh "\n";
        } else
        {
            warn "\t!!!Ignoring bad row in tsm_inex ($row)\n";
        }
    }

    return 1;
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::tsm_inclexcl - generate TSM inex.list file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::tsm_inclexcl;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::tsm_inclexcl->new(
			'name'		=> '/opt/tivoli/tsm/client/ba/bin/inex.list',
			'inex'	=> { ... },
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::tsm_inclexcl> module provides a
B<PSGConf> action class for generating a TSM inex.list file.

The B<PSGConf::Action::GenerateFile::tsm_inclexcl> class is derived from
the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generate the inex.list file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::tsm_inclexcl> class supports the
following attributes:

=over 4

=item I<inex>

A table mapping the entire file contents, uses only the first 3 colums, with
the first 2 being required.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


