
###
###  Copyright 2000-2008 University of Illinois Board of Trustees
###  All rights reserved.
###
###  PSGConf::Data::FileTest - data obj class for running test(1) operators.
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Data::FileTest;

use strict;

use PSGConf::Data;

our @ISA = qw(PSGConf::Data);

###############################################################################
###  methods
###############################################################################

sub _test
{
    my ( $self, $value ) = @_;
    my ($res);

    die "value required\n"
      if ( !defined $value );
}

sub read
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -r $value );
}

sub write
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -w $value );
}

sub execute
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -x $value );
}

sub owner
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -o $value );
}

sub exists
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -e $value );
}

sub zero
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -z $value );
}

sub nonzero
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -s $value );
}

sub plain
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -f $value );
}

sub directory
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -d $value );
}

sub symlink
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -l $value );
}

sub socket
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -S $value );
}

sub fifo
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -p $value );
}

sub block
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -b $value );
}

sub character
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -c $value );
}

sub setuid
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -u $value );
}

sub setgid
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -g $value );
}

sub sticky
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -k $value );
}

sub filehandle
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -t $value );
}

sub text
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -T $value );
}

sub binary
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -B $value );
}

sub modifytime
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -M $value );
}

sub accesstime
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -A $value );
}

sub inodetime
{
    my ( $self, $value ) = @_;

    $self->_test($value);
    return ( -C $value );
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Data::FileTest - psgconf data obj class for signalling config errors

=head1 SYNOPSIS

  use PSGConf::Data::FileTest;

  $psgconf->register_data(
		'filetest'	=> PSGConf::Data::FileTest->new()
	);

=head1 DESCRIPTION

The B<PSGConf::Data::FileTest> module provides a class that can
be used to test for the presense of files on the filesystem.
Although it uses the Data object interface, it does not actually
encapsulate a value.

The B<PSGConf::Data::FileTest> defines/overrides the following methods:

=over 4

=item read()

=item write()

=item execute()

=item owner()

=item exists()

=item zero()

=item nonzero()

=item plain()

=item directory()

=item symlink()

=item socket()

=item fifo()

=item block()

=item character()

=item setuid()

=item setgid()

=item sticky()

=item filehandle()

=item text()

=item binary()

=item modifytime()

=item accesstime()

=item inodetime()

=back

=head1 ATTRIBUTION

Thanks to Seth Leichter <leichter@uiuc.edu> for the idea for the data module.

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Data>

=cut

